@@ -59,23 +59,23 @@ class UserPerformance:
                 df[("monitored_worktime_hour", phase)] / df[("monitored_worktime_hour", "sum")]
             )
             # AnnoFab時間の比率から、Annowork時間を予測する
-            df[("prediction_actual_worktime_hour", phase)] = (
+            df[("actual_worktime_hour", phase)] = (
                 df[("actual_worktime_hour", "sum")] * df[("monitored_worktime_ratio", phase)]
             )
 
             # 生産性を算出
-            df[("monitored_worktime/input_data_count", phase)] = (
+            df[("monitored_worktime_hour/input_data_count", phase)] = (
                 df[("monitored_worktime_hour", phase)] / df[("input_data_count", phase)]
             )
-            df[("actual_worktime/input_data_count", phase)] = (
-                df[("prediction_actual_worktime_hour", phase)] / df[("input_data_count", phase)]
+            df[("actual_worktime_hour/input_data_count", phase)] = (
+                df[("actual_worktime_hour", phase)] / df[("input_data_count", phase)]
             )
 
-            df[("monitored_worktime/annotation_count", phase)] = (
+            df[("monitored_worktime_hour/annotation_count", phase)] = (
                 df[("monitored_worktime_hour", phase)] / df[("annotation_count", phase)]
             )
-            df[("actual_worktime/annotation_count", phase)] = (
-                df[("prediction_actual_worktime_hour", phase)] / df[("annotation_count", phase)]
+            df[("actual_worktime_hour/annotation_count", phase)] = (
+                df[("actual_worktime_hour", phase)] / df[("annotation_count", phase)]
             )
 
         phase = TaskPhase.ANNOTATION.value
@@ -265,14 +265,14 @@ class UserPerformance:
         )
 
         actual_worktime_columns = [("actual_worktime_hour", "sum")] + [
-            ("prediction_actual_worktime_hour", phase) for phase in phase_list
+            ("actual_worktime_hour", phase) for phase in phase_list
         ]
 
         productivity_columns = (
-            [("monitored_worktime/input_data_count", phase) for phase in phase_list]
-            + [("actual_worktime/input_data_count", phase) for phase in phase_list]
-            + [("monitored_worktime/annotation_count", phase) for phase in phase_list]
-            + [("actual_worktime/annotation_count", phase) for phase in phase_list]
+            [("monitored_worktime_hour/input_data_count", phase) for phase in phase_list]
+            + [("actual_worktime_hour/input_data_count", phase) for phase in phase_list]
+            + [("monitored_worktime_hour/annotation_count", phase) for phase in phase_list]
+            + [("actual_worktime_hour/annotation_count", phase) for phase in phase_list]
         )
 
         inspection_comment_columns = [
@@ -387,7 +387,6 @@ class UserPerformance:
             "input_data_count",
             "annotation_count",
             "actual_worktime_hour",
-            "prediction_actual_worktime_hour",
             "pointed_out_inspection_comment_count",
             "rejected_count",
         ]
@@ -416,15 +415,13 @@ class UserPerformance:
                 plot_height=self.PLOT_HEIGHT,
                 title=title,
                 x_axis_label="累計作業時間[hour]",
-                y_axis_label="アノテーションあたり作業時間[hour/annotation]",
+                y_axis_label="アノテーションあたり作業時間[minute/annotation]",
             )
 
         if worktime_type == WorktimeType.ACTUAL:
             worktime_name = "実績時間"
-            worktime_key_for_phase = "prediction_actual"
         elif worktime_type == WorktimeType.MONITORED:
             worktime_name = "計測時間"
-            worktime_key_for_phase = WorktimeType.MONITORED.value
 
         logger.debug(f"{output_file} を出力します。")
 
@@ -440,9 +437,15 @@ class UserPerformance:
 
         df["biography"] = df["biography"].fillna("")
 
+        x_column = f"{worktime_type.value}_worktime_hour"
+        y_column = f"{worktime_type.value}_worktime_minute/annotation_count"
+        # 分単位の生産性を算出する
+        for phase in self.phase_list:
+            df[(f"{worktime_type.value}_worktime_minute/annotation_count", phase)] = (
+                df[(f"{worktime_type.value}_worktime_hour/annotation_count", phase)] * 60
+            )
+
         for biography_index, biography in enumerate(sorted(set(df["biography"]))):
-            x_column = f"{worktime_key_for_phase}_worktime_hour"
-            y_column = f"{worktime_type.value}_worktime/annotation_count"
             for fig, phase in zip(figure_list, self.phase_list):
                 filtered_df = df[
                     (df["biography"] == biography) & df[(x_column, phase)].notna() & df[(y_column, phase)].notna()
@@ -463,11 +466,11 @@ class UserPerformance:
         for fig, phase in zip(figure_list, self.phase_list):
             average_value = self._get_average_value(
                 df,
-                numerator_column=(f"{worktime_key_for_phase}_worktime_hour", phase),
+                numerator_column=(f"{worktime_type.value}_worktime_hour", phase),
                 denominator_column=("annotation_count", phase),
             )
             self._plot_average_line(fig, average_value, dimension="width")
-            quartile = self._get_quartile_value(df, (f"{worktime_type.value}_worktime/annotation_count", phase))
+            quartile = self._get_quartile_value(df, (f"{worktime_type.value}_worktime_hour/annotation_count", phase))
             self._plot_quartile_line(fig, quartile, dimension="width")
 
         for fig, phase in zip(figure_list, self.phase_list):
@@ -475,12 +478,12 @@ class UserPerformance:
                 "user_id_",
                 "username_",
                 "biography_",
-                f"{worktime_key_for_phase}_worktime_hour_{phase}",
+                f"{worktime_type.value}_worktime_hour_{phase}",
                 f"task_count_{phase}",
                 f"input_data_count_{phase}",
                 f"annotation_count_{phase}",
-                f"{worktime_type.value}_worktime/input_data_count_{phase}",
-                f"{worktime_type.value}_worktime/annotation_count_{phase}",
+                f"{worktime_type.value}_worktime_hour/input_data_count_{phase}",
+                f"{worktime_type.value}_worktime_hour/annotation_count_{phase}",
             ]
             if worktime_type == WorktimeType.ACTUAL:
                 tooltip_item.append("last_working_date_")
@@ -630,18 +633,17 @@ class UserPerformance:
         if not self._validate_df_for_output(output_file):
             return
 
-        if worktime_type == WorktimeType.ACTUAL:
-            worktime_key_for_phase = "prediction_actual"
-        elif worktime_type == WorktimeType.MONITORED:
-            worktime_key_for_phase = WorktimeType.MONITORED.value
-
         # numpy.inf が含まれていると散布図を出力できないので置換する
         df = self.df.replace(numpy.inf, numpy.nan)
+        for phase in self.phase_list:
+            df[(f"{worktime_type.value}_worktime_minute/annotation_count", phase)] = (
+                df[(f"{worktime_type.value}_worktime_hour/annotation_count", phase)] * 60
+            )
 
         def create_figure(title: str, x_axis_label: str, y_axis_label: str) -> bokeh.plotting.Figure:
             return figure(
-                plot_width=1200,
-                plot_height=800,
+                plot_width=self.PLOT_WIDTH,
+                plot_height=self.PLOT_HEIGHT,
                 title=title,
                 x_axis_label=x_axis_label,
                 y_axis_label=y_axis_label,
@@ -651,18 +653,20 @@ class UserPerformance:
 
         figure_list = [
             create_figure(
-                title=f"アノテーションあたり作業時間とタスクあたり差し戻し回数の関係", x_axis_label="アノテーションあたり作業時間", y_axis_label="タスクあたり差し戻し回数"
+                title=f"アノテーションあたり作業時間とタスクあたり差し戻し回数の関係",
+                x_axis_label="アノテーションあたり作業時間[minute/annotation]",
+                y_axis_label="タスクあたり差し戻し回数",
             ),
             create_figure(
                 title=f"アノテーションあたり作業時間とアノテーションあたり検査コメント数の関係",
-                x_axis_label="アノテーションあたり作業時間",
+                x_axis_label="アノテーションあたり作業時間[minute/annotation]",
                 y_axis_label="アノテーションあたり検査コメント数",
             ),
         ]
         column_pair_list = [
-            (f"{worktime_type.value}_worktime/annotation_count", "rejected_count/task_count"),
+            (f"{worktime_type.value}_worktime_minute/annotation_count", "rejected_count/task_count"),
             (
-                f"{worktime_type.value}_worktime/annotation_count",
+                f"{worktime_type.value}_worktime_minute/annotation_count",
                 "pointed_out_inspection_comment_count/annotation_count",
             ),
         ]
@@ -683,14 +687,14 @@ class UserPerformance:
                     x_column_name=f"{x_column}_{phase}",
                     y_column_name=f"{y_column}_{phase}",
                     text_column_name="username_",
-                    size_column_name=f"{worktime_key_for_phase}_worktime_hour_{phase}",
+                    size_column_name=f"{worktime_type.value}_worktime_hour_{phase}",
                     legend_label=biography,
                     color=get_color_from_palette(biography_index),
                 )
 
         x_average_value = self._get_average_value(
             df,
-            numerator_column=(f"{worktime_key_for_phase}_worktime_hour", phase),
+            numerator_column=(f"{worktime_type.value}_worktime_hour", phase),
             denominator_column=("annotation_count", phase),
         )
         for column_pair, fig in zip(
@@ -705,7 +709,7 @@ class UserPerformance:
             )
             self._plot_average_line(fig, y_average_value, dimension="width")
 
-        x_quartile = self._get_quartile_value(df, (f"{worktime_type.value}_worktime/annotation_count", phase))
+        x_quartile = self._get_quartile_value(df, (f"{worktime_type.value}_worktime_hour/annotation_count", phase))
         for column, fig in zip(
             ["rejected_count/task_count", "pointed_out_inspection_comment_count/annotation_count"],
             figure_list,
@@ -719,12 +723,12 @@ class UserPerformance:
                 "user_id_",
                 "username_",
                 "biography_",
-                f"{worktime_key_for_phase}_worktime_hour_{phase}",
+                f"{worktime_type.value}_worktime_hour_{phase}",
                 f"task_count_{phase}",
                 f"input_data_count_{phase}",
                 f"annotation_count_{phase}",
-                f"{worktime_type.value}_worktime/input_data_count_{phase}",
-                f"{worktime_type.value}_worktime/annotation_count_{phase}",
+                f"{worktime_type.value}_worktime_hour/input_data_count_{phase}",
+                f"{worktime_type.value}_worktime_hour/annotation_count_{phase}",
                 f"rejected_count_{phase}",
                 f"pointed_out_inspection_comment_count_{phase}",
                 f"rejected_count/task_count_{phase}",
